==> haskell-rsa-2.4.1-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-2YhYG1C2aCx3ShpWLm6Zm8
key:                  RSA-2.4.1-2YhYG1C2aCx3ShpWLm6Zm8
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  052d45e4e8900d175b93da8543863daa
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-8.10.4/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/RSA-2.4.1
hs-libraries:         HSRSA-2.4.1-2YhYG1C2aCx3ShpWLm6Zm8
depends:
    SHA-1.6.4.4-5FIK7Bs8eLkISed49HyXzA base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 crypto-api-0.13.3-29xf6phcoYS3UxI8fy8p1u
    crypto-pubkey-types-0.4.3-JFD7BlkQgRT8V3jsYnxS7l

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rsa-2.4.1-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rsa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 RSA
version:              2.4.1
visibility:           public
id:                   RSA-2.4.1-FtzS6n2kWEcBOO0F7jFn23
key:                  RSA-2.4.1-FtzS6n2kWEcBOO0F7jFn23
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@galois.com>
author:               Adam Wick <awick@galois.com>
stability:            stable
synopsis:
    Implementation of RSA, using the padding schemes of PKCS#1 v2.1.

description:
    This library implements the RSA encryption and signature
    algorithms for arbitrarily-sized ByteStrings. While the
    implementations work, they are not necessarily the fastest ones
    on the planet. Particularly key generation. The algorithms
    included are based of RFC 3447, or the Public-Key Cryptography
    Standard for RSA, version 2.1 (a.k.a, PKCS#1 v2.1).

category:             Cryptography, Codec
abi:                  1ed4ee09675bf62a4a5c03ea8a5b2436
exposed:              True
exposed-modules:
    Codec.Crypto.RSA Codec.Crypto.RSA.Exceptions Codec.Crypto.RSA.Pure

import-dirs:          /usr/lib/ghc-8.10.4/site-local/RSA-2.4.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/RSA-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/RSA-2.4.1
hs-libraries:         HSRSA-2.4.1-FtzS6n2kWEcBOO0F7jFn23
depends:
    SHA-1.6.4.4-5FIK7Bs8eLkISed49HyXzA base-4.14.1.0 binary-0.8.8.0
    bytestring-0.10.12.0 crypto-api-0.13.3-29xf6phcoYS3UxI8fy8p1u
    crypto-pubkey-types-0.4.3-1KnMFUeLMWtsXUHm27BPz

haddock-interfaces:   /usr/share/doc/haskell-rsa/html/RSA.haddock
haddock-html:         /usr/share/doc/haskell-rsa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
